@@ -1,11 +1,11 @@
+import logging
+
 import pytest
 
 from twine import auth
 from twine import exceptions
 from twine import utils
 
-cred = auth.CredentialInput
-
 
 @pytest.fixture
 def config() -> utils.RepositoryConfig:
@@ -20,7 +20,7 @@ def test_get_password_keyring_overrides_prompt(monkeypatch, config):
 
     monkeypatch.setattr(auth, "keyring", MockKeyring)
 
-    pw = auth.Resolver(config, cred("user")).password
+    pw = auth.Resolver(config, auth.CredentialInput("user")).password
     assert pw == "user@system sekure pa55word"
 
 
@@ -32,37 +32,41 @@ def test_get_password_keyring_defers_to_prompt(monkeypatch, entered_password, co
 
     monkeypatch.setattr(auth, "keyring", MockKeyring)
 
-    pw = auth.Resolver(config, cred("user")).password
+    pw = auth.Resolver(config, auth.CredentialInput("user")).password
     assert pw == "entered pw"
 
 
 def test_no_password_defers_to_prompt(monkeypatch, entered_password, config):
     config.update(password=None)
-    pw = auth.Resolver(config, cred("user")).password
+    pw = auth.Resolver(config, auth.CredentialInput("user")).password
     assert pw == "entered pw"
 
 
 def test_empty_password_bypasses_prompt(monkeypatch, entered_password, config):
     config.update(password="")
-    pw = auth.Resolver(config, cred("user")).password
+    pw = auth.Resolver(config, auth.CredentialInput("user")).password
     assert pw == ""
 
 
 def test_no_username_non_interactive_aborts(config):
     with pytest.raises(exceptions.NonInteractive):
-        auth.Private(config, cred("user")).password
+        auth.Private(config, auth.CredentialInput("user")).password
 
 
 def test_no_password_non_interactive_aborts(config):
     with pytest.raises(exceptions.NonInteractive):
-        auth.Private(config, cred("user")).password
+        auth.Private(config, auth.CredentialInput("user")).password
 
 
-def test_get_username_and_password_keyring_overrides_prompt(monkeypatch, config):
+def test_get_username_and_password_keyring_overrides_prompt(
+    monkeypatch, config, caplog
+):
+    caplog.set_level(logging.INFO, "twine")
+
     class MockKeyring:
         @staticmethod
         def get_credential(system, user):
-            return cred(
+            return auth.CredentialInput(
                 "real_user", "real_user@{system} sekure pa55word".format(**locals())
             )
 
@@ -75,10 +79,16 @@ def test_get_username_and_password_keyring_overrides_prompt(monkeypatch, config)
 
     monkeypatch.setattr(auth, "keyring", MockKeyring)
 
-    res = auth.Resolver(config, cred())
+    res = auth.Resolver(config, auth.CredentialInput())
+
     assert res.username == "real_user"
     assert res.password == "real_user@system sekure pa55word"
 
+    assert caplog.messages == [
+        "username set from keyring",
+        "password set from keyring",
+    ]
+
 
 @pytest.fixture
 def keyring_missing_get_credentials(monkeypatch):
@@ -94,21 +104,21 @@ def entered_username(monkeypatch):
 def test_get_username_keyring_missing_get_credentials_prompts(
     entered_username, keyring_missing_get_credentials, config
 ):
-    assert auth.Resolver(config, cred()).username == "entered user"
+    assert auth.Resolver(config, auth.CredentialInput()).username == "entered user"
 
 
 def test_get_username_keyring_missing_non_interactive_aborts(
     entered_username, keyring_missing_get_credentials, config
 ):
     with pytest.raises(exceptions.NonInteractive):
-        auth.Private(config, cred()).username
+        auth.Private(config, auth.CredentialInput()).username
 
 
 def test_get_password_keyring_missing_non_interactive_aborts(
     entered_username, keyring_missing_get_credentials, config
 ):
     with pytest.raises(exceptions.NonInteractive):
-        auth.Private(config, cred("user")).password
+        auth.Private(config, auth.CredentialInput("user")).password
 
 
 @pytest.fixture
@@ -138,7 +148,7 @@ def keyring_no_backends_get_credential(monkeypatch):
 def test_get_username_runtime_error_suppressed(
     entered_username, keyring_no_backends_get_credential, recwarn, config
 ):
-    assert auth.Resolver(config, cred()).username == "entered user"
+    assert auth.Resolver(config, auth.CredentialInput()).username == "entered user"
     assert len(recwarn) == 1
     warning = recwarn.pop(UserWarning)
     assert "fail!" in str(warning)
@@ -147,7 +157,7 @@ def test_get_username_runtime_error_suppressed(
 def test_get_password_runtime_error_suppressed(
     entered_password, keyring_no_backends, recwarn, config
 ):
-    assert auth.Resolver(config, cred("user")).password == "entered pw"
+    assert auth.Resolver(config, auth.CredentialInput("user")).password == "entered pw"
     assert len(recwarn) == 1
     warning = recwarn.pop(UserWarning)
     assert "fail!" in str(warning)
@@ -162,4 +172,33 @@ def test_get_username_return_none(entered_username, monkeypatch, config):
             return None
 
     monkeypatch.setattr(auth, "keyring", FailKeyring())
-    assert auth.Resolver(config, cred()).username == "entered user"
+    assert auth.Resolver(config, auth.CredentialInput()).username == "entered user"
+
+
+def test_logs_cli_values(caplog):
+    caplog.set_level(logging.INFO, "twine")
+
+    res = auth.Resolver(config, auth.CredentialInput("username", "password"))
+
+    assert res.username == "username"
+    assert res.password == "password"
+
+    assert caplog.messages == [
+        "username set by command options",
+        "password set by command options",
+    ]
+
+
+def test_logs_config_values(config, caplog):
+    caplog.set_level(logging.INFO, "twine")
+
+    config.update(username="username", password="password")
+    res = auth.Resolver(config, auth.CredentialInput())
+
+    assert res.username == "username"
+    assert res.password == "password"
+
+    assert caplog.messages == [
+        "username set from config file",
+        "password set from config file",
+    ]
