@@ -13,6 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import argparse
+import logging
 import os.path
 import textwrap
 
@@ -55,20 +56,42 @@ def test_settings_transforms_repository_config(tmpdir):
     assert s.disable_progress_bar is False
 
 
+@pytest.mark.parametrize(
+    "verbose, log_level", [(True, logging.INFO), (False, logging.WARNING)]
+)
+def test_setup_logging(verbose, log_level):
+    """Set log level based on verbose field."""
+    settings.Settings(verbose=verbose)
+
+    logger = logging.getLogger("twine")
+
+    assert logger.level == log_level
+
+
+@pytest.mark.parametrize(
+    "verbose",
+    [True, False],
+)
+def test_print_config_path_if_verbose(tmpdir, capsys, make_settings, verbose):
+    """Print the location of the .pypirc config used by the user."""
+    pypirc = os.path.join(str(tmpdir), ".pypirc")
+
+    make_settings(verbose=verbose)
+
+    captured = capsys.readouterr()
+
+    if verbose:
+        assert captured.out == f"Using configuration from {pypirc}\n"
+    else:
+        assert captured.out == ""
+
+
 def test_identity_requires_sign():
     """Raise an exception when user provides identity but doesn't require sigining."""
     with pytest.raises(exceptions.InvalidSigningConfiguration):
         settings.Settings(sign=False, identity="fakeid")
 
 
-def test_password_not_required_if_client_cert(entered_password):
-    """Don't set password when only client_cert is provided."""
-    test_client_cert = "/random/path"
-    settings_obj = settings.Settings(username="fakeuser", client_cert=test_client_cert)
-    assert not settings_obj.password
-    assert settings_obj.client_cert == test_client_cert
-
-
 @pytest.mark.parametrize("client_cert", [None, ""])
 def test_password_is_required_if_no_client_cert(client_cert, entered_password):
     """Set password when client_cert is not provided."""
@@ -76,16 +99,32 @@ def test_password_is_required_if_no_client_cert(client_cert, entered_password):
     assert settings_obj.password == "entered pw"
 
 
-def test_client_cert_is_set_and_password_not_if_both_given(entered_password):
+def test_client_cert_and_password_both_set_if_given():
     """Set password and client_cert when both are provided."""
     client_cert = "/random/path"
     settings_obj = settings.Settings(
         username="fakeuser", password="anything", client_cert=client_cert
     )
-    assert not settings_obj.password
+    assert settings_obj.password == "anything"
     assert settings_obj.client_cert == client_cert
 
 
+def test_password_required_if_no_client_cert_and_non_interactive():
+    """Raise exception if no password or client_cert when non interactive."""
+    settings_obj = settings.Settings(username="fakeuser", non_interactive=True)
+    with pytest.raises(exceptions.NonInteractive):
+        settings_obj.password
+
+
+def test_no_password_prompt_if_client_cert_and_non_interactive(entered_password):
+    """Don't prompt for password when client_cert is provided and non interactive."""
+    client_cert = "/random/path"
+    settings_obj = settings.Settings(
+        username="fakeuser", client_cert=client_cert, non_interactive=True
+    )
+    assert not settings_obj.password
+
+
 class TestArgumentParsing:
     @staticmethod
     def parse_args(args):
