@@ -12,25 +12,33 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 __all__ = (
-    "__title__", "__summary__", "__uri__", "__version__", "__author__",
-    "__email__", "__license__", "__copyright__",
+    "__title__",
+    "__summary__",
+    "__uri__",
+    "__version__",
+    "__author__",
+    "__email__",
+    "__license__",
+    "__copyright__",
 )
 
 __copyright__ = "Copyright 2019 Donald Stufft and individual contributors"
 
-try:
-    import importlib.metadata as importlib_metadata
-except ImportError:
+import sys
+
+if sys.version_info[:2] >= (3, 8):
+    from importlib import metadata as importlib_metadata
+else:
     import importlib_metadata
 
 
-metadata = importlib_metadata.metadata('twine')
+metadata = importlib_metadata.metadata("twine")
 
 
-__title__ = metadata['name']
-__summary__ = metadata['summary']
-__uri__ = metadata['home-page']
-__version__ = metadata['version']
-__author__ = metadata['author']
-__email__ = metadata['author-email']
-__license__ = metadata['license']
+__title__ = metadata["name"]
+__summary__ = metadata["summary"]
+__uri__ = metadata["home-page"]
+__version__ = metadata["version"]
+__author__ = metadata["author"]
+__email__ = metadata["author-email"]
+__license__ = metadata["license"]
