@@ -12,50 +12,58 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import argparse
-import pkg_resources
-import setuptools
+from typing import Any, Dict, List, Tuple
 
-import tqdm
+import pkg_resources
+import pkginfo
 import requests
 import requests_toolbelt
-import pkginfo
+import setuptools
+import tqdm
 
 import twine
-from twine._installed import Installed
+from twine import _installed
+
+args = argparse.Namespace()
 
 
-def _registered_commands(group='twine.registered_commands'):
+def _registered_commands(
+    group: str = "twine.registered_commands",
+) -> Dict[str, pkg_resources.EntryPoint]:
     registered_commands = pkg_resources.iter_entry_points(group=group)
     return {c.name: c for c in registered_commands}
 
 
-def list_dependencies_and_versions():
+def list_dependencies_and_versions() -> List[Tuple[str, str]]:
     return [
-        ('pkginfo', Installed(pkginfo).version),
-        ('requests', requests.__version__),
-        ('setuptools', setuptools.__version__),
-        ('requests-toolbelt', requests_toolbelt.__version__),
-        ('tqdm', tqdm.__version__),
+        ("pkginfo", _installed.Installed(pkginfo).version),
+        ("requests", requests.__version__),
+        ("setuptools", setuptools.__version__),
+        ("requests-toolbelt", requests_toolbelt.__version__),
+        ("tqdm", tqdm.__version__),
     ]
 
 
-def dep_versions():
-    return ', '.join(
-        '{}: {}'.format(*dependency)
-        for dependency in list_dependencies_and_versions()
+def dep_versions() -> str:
+    return ", ".join(
+        "{}: {}".format(*dependency) for dependency in list_dependencies_and_versions()
     )
 
 
-def dispatch(argv):
+def dispatch(argv: List[str]) -> Any:
     registered_commands = _registered_commands()
     parser = argparse.ArgumentParser(prog="twine")
     parser.add_argument(
         "--version",
         action="version",
-        version="%(prog)s version {} ({})".format(
-            twine.__version__,
-            dep_versions(),
-        ),
+        version="%(prog)s version {} ({})".format(twine.__version__, dep_versions()),
+    )
+    parser.add_argument(
+        "--no-color",
+        default=False,
+        required=False,
+        action="store_true",
+        help="disable colored output",
     )
     parser.add_argument(
         "command",
@@ -67,7 +75,7 @@ def dispatch(argv):
         nargs=argparse.REMAINDER,
     )
 
-    args = parser.parse_args(argv)
+    parser.parse_args(argv, namespace=args)
 
     main = registered_commands[args.command].load()
 
