@@ -11,25 +11,22 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Dict, IO, Optional, Union, Sequence, Tuple
-
-import collections
 import hashlib
 import io
 import os
 import subprocess
-from hashlib import blake2b
+from typing import Dict, NamedTuple, Optional, Sequence, Tuple, Union
 
-import pkginfo
 import pkg_resources
+import pkginfo
 
-from twine.wheel import Wheel
-from twine.wininst import WinInst
 from twine import exceptions
+from twine import wheel
+from twine import wininst
 
 DIST_TYPES = {
-    "bdist_wheel": Wheel,
-    "bdist_wininst": WinInst,
+    "bdist_wheel": wheel.Wheel,
+    "bdist_wininst": wininst.WinInst,
     "bdist_egg": pkginfo.BDist,
     "sdist": pkginfo.SDist,
 }
@@ -43,7 +40,7 @@ DIST_EXTENSIONS = {
     ".zip": "sdist",
 }
 
-MetadataValue = Union[str, Sequence[str], Tuple[str, IO, str]]
+MetadataValue = Union[str, Sequence[str]]
 
 
 class PackageFile:
@@ -62,8 +59,8 @@ class PackageFile:
         self.python_version = python_version
         self.filetype = filetype
         self.safe_name = pkg_resources.safe_name(metadata.name)
-        self.signed_filename = self.filename + '.asc'
-        self.signed_basefilename = self.basefilename + '.asc'
+        self.signed_filename = self.filename + ".asc"
+        self.signed_basefilename = self.basefilename + ".asc"
         self.gpg_signature: Optional[Tuple[str, bytes]] = None
 
         hasher = HashManager(filename)
@@ -75,16 +72,21 @@ class PackageFile:
         self.blake2_256_digest = hexdigest.blake2
 
     @classmethod
-    def from_filename(cls, filename: str, comment: None) -> 'PackageFile':
+    def from_filename(cls, filename: str, comment: Optional[str]) -> "PackageFile":
         # Extract the metadata from the package
         for ext, dtype in DIST_EXTENSIONS.items():
             if filename.endswith(ext):
-                meta = DIST_TYPES[dtype](filename)
-                break
+                try:
+                    meta = DIST_TYPES[dtype](filename)
+                except EOFError:
+                    raise exceptions.InvalidDistribution(
+                        "Invalid distribution file: '%s'" % os.path.basename(filename)
+                    )
+                else:
+                    break
         else:
             raise exceptions.InvalidDistribution(
-                "Unknown distribution format: '%s'" %
-                os.path.basename(filename)
+                "Unknown distribution format: '%s'" % os.path.basename(filename)
             )
 
         # If pkginfo encounters a metadata version it doesn't support, it may
@@ -92,8 +94,7 @@ class PackageFile:
         # and version
         if not (meta.name and meta.version):
             raise exceptions.InvalidDistribution(
-                "Invalid distribution metadata. Try upgrading twine if "
-                "possible."
+                "Invalid distribution metadata. Try upgrading twine if possible."
             )
 
         py_version: Optional[str]
@@ -115,11 +116,9 @@ class PackageFile:
             # identify release
             "name": self.safe_name,
             "version": meta.version,
-
             # file content
             "filetype": self.filetype,
             "pyversion": self.python_version,
-
             # additional meta-data
             "metadata_version": meta.metadata_version,
             "summary": meta.summary,
@@ -139,12 +138,10 @@ class PackageFile:
             "md5_digest": self.md5_digest,
             "sha256_digest": self.sha2_digest,
             "blake2_256_digest": self.blake2_256_digest,
-
             # PEP 314
             "provides": meta.provides,
             "requires": meta.requires,
             "obsoletes": meta.obsoletes,
-
             # Metadata 1.2
             "project_urls": meta.project_urls,
             "provides_dist": meta.provides_dist,
@@ -152,31 +149,26 @@ class PackageFile:
             "requires_dist": meta.requires_dist,
             "requires_external": meta.requires_external,
             "requires_python": meta.requires_python,
-
             # Metadata 2.1
             "provides_extras": meta.provides_extras,
             "description_content_type": meta.description_content_type,
         }
 
         if self.gpg_signature is not None:
-            data['gpg_signature'] = self.gpg_signature
+            data["gpg_signature"] = self.gpg_signature
 
         return data
 
     def add_gpg_signature(
-        self,
-        signature_filepath: str,
-        signature_filename: str
-    ):
+        self, signature_filepath: str, signature_filename: str
+    ) -> None:
         if self.gpg_signature is not None:
-            raise exceptions.InvalidDistribution(
-                'GPG Signature can only be added once'
-            )
+            raise exceptions.InvalidDistribution("GPG Signature can only be added once")
 
         with open(signature_filepath, "rb") as gpg:
             self.gpg_signature = (signature_filename, gpg.read())
 
-    def sign(self, sign_with: str, identity: Optional[str]):
+    def sign(self, sign_with: str, identity: Optional[str]) -> None:
         print(f"Signing {self.basefilename}")
         gpg_args: Tuple[str, ...] = (sign_with, "--detach-sign")
         if identity:
@@ -187,14 +179,15 @@ class PackageFile:
         self.add_gpg_signature(self.signed_filename, self.signed_basefilename)
 
     @classmethod
-    def run_gpg(cls, gpg_args):
+    def run_gpg(cls, gpg_args: Tuple[str, ...]) -> None:
         try:
             subprocess.check_call(gpg_args)
             return
         except FileNotFoundError:
             if gpg_args[0] != "gpg":
                 raise exceptions.InvalidSigningExecutable(
-                    "{} executable not available.".format(gpg_args[0]))
+                    "{} executable not available.".format(gpg_args[0])
+                )
 
         print("gpg executable not available. Attempting fallback to gpg2.")
         try:
@@ -208,7 +201,10 @@ class PackageFile:
             )
 
 
-Hexdigest = collections.namedtuple('Hexdigest', ['md5', 'sha2', 'blake2'])
+class Hexdigest(NamedTuple):
+    md5: Optional[str]
+    sha2: Optional[str]
+    blake2: Optional[str]
 
 
 class HashManager:
@@ -231,8 +227,11 @@ class HashManager:
         self._sha2_hasher = hashlib.sha256()
 
         self._blake_hasher = None
-        if blake2b is not None:
-            self._blake_hasher = blake2b(digest_size=256 // 8)
+        try:
+            self._blake_hasher = hashlib.blake2b(digest_size=256 // 8)
+        except ValueError:
+            # FIPS mode disables blake2
+            pass
 
     def _md5_update(self, content: bytes) -> None:
         if self._md5_hasher is not None:
@@ -264,7 +263,7 @@ class HashManager:
     def hash(self) -> None:
         """Hash the file contents."""
         with open(self.filename, "rb") as fp:
-            for content in iter(lambda: fp.read(io.DEFAULT_BUFFER_SIZE), b''):
+            for content in iter(lambda: fp.read(io.DEFAULT_BUFFER_SIZE), b""):
                 self._md5_update(content)
                 self._sha2_update(content)
                 self._blake_update(content)
